@@ -44,7 +44,9 @@ unsigned char *extract_zip(f_state *s, u_int64_t c_offset, unsigned char *founda
 	u_int64_t					file_size = 0;
 	int							oOffice = FALSE;
 	char						comment[32];
-
+	localFH.genFlag=0;
+	localFH.compressed=0;
+	localFH.uncompressed =0;
 	if (buflen < 100)
 		return NULL;
 
@@ -75,32 +77,36 @@ unsigned char *extract_zip(f_state *s, u_int64_t c_offset, unsigned char *founda
 		needle->suffix = "zip";
 		}
 
-	while (1)	/*Jump through each local file header until the central directory structure is reached, much faster than searching */
+	
+	while (1)	//Jump through each local file header until the central directory structure is reached, much faster than searching 
 		{
-		if (foundat[2] == '\x03' && foundat[3] == '\x04')	/*Verfiy we are looking at a local file header*/
+		
+		if (foundat[2] == '\x03' && foundat[3] == '\x04')	//Verfiy we are looking at a local file header//
 			{
+			
+			localFH.compression=htos(&foundat[8], LITTLE_ENDIAN);
 			localFH.compressed = htoi(&foundat[18], LITTLE_ENDIAN);
 			localFH.uncompressed = htoi(&foundat[22], LITTLE_ENDIAN);
 			localFH.filename_length = htos(&foundat[26], LITTLE_ENDIAN);
-			localFH.extra_length = htos(&foundat[28], LITTLE_ENDIAN);
-			localFH.genFlag = htos(&foundat[8], LITTLE_ENDIAN);
+			localFH.extra_length = htos(&foundat[28], LITTLE_ENDIAN);;
+			localFH.genFlag = htos(&foundat[6], LITTLE_ENDIAN);	
 
-			/* Sanity checking*/
+			// Sanity checking
 			if (localFH.compressed > needle->max_len)
 				return foundat + needle->header_len;
 
 			if (localFH.filename_length > 100)
 				return foundat + needle->header_len;
 
-			/*Check if we should grab more from the disk*/
+			//Check if we should grab more from the disk
 			if (localFH.compressed + 30 > buflen - (foundat - buf))
 				{
-				return NULL;								/*Go back grab more and try again*/
+				return NULL;								
 				}
+				
+			//Size of the local file header data structure
+			foundat += 30;									
 
-			foundat += 30;									/*Size of the local file header data structure*/
-#ifdef DEBUG
-#endif
 			if (needle->suffix == "zip")
 				{
 				if (strncmp((char *)foundat, "content.xml", 11) == 0 && needle->suffix == "zip")
@@ -118,23 +124,33 @@ unsigned char *extract_zip(f_state *s, u_int64_t c_offset, unsigned char *founda
 				}
 
 			foundat += localFH.compressed;
-
 			foundat += localFH.filename_length;
 			foundat += localFH.extra_length;
+			
 			if (localFH.genFlag == 8)
-			{
-#ifdef DEBUG
-				printf("We have extra stuff!!!");
+				{
+#ifdef DEBUG	
+					fprintf(stderr,"We have extra stuff!!!");
 #endif
-			}
+				}
+			
+			
+			if(localFH.genFlag & 1<<3 && localFH.uncompressed==0 &&  localFH.compressed==0 )
+				{
+#ifdef DEBUG
+				fprintf(stderr,"No data to jmp Just search for the next file Footer\n",localFH.genFlag);
+#endif
+				break;
+				}
 
-#ifdef DEBUG
-			printf("localFH.compressed:=%d  localFH.uncompressed:=%d\n",
-				   localFH.compressed,
-				   localFH.uncompressed);
-			printx(foundat, 0, 16);
-#endif
-			}
+	#ifdef DEBUG
+				printf("localFH.compressed:=%d  localFH.uncompressed:=%d\n\t jumping %d bytes filename=%d bytes",
+					   localFH.compressed,
+					   localFH.uncompressed,localFH.filename_length+localFH.compressed+localFH.extra_length,localFH.filename_length);
+				printx(foundat, 0, 16);
+	#endif
+
+			}	
 		else if (oOffice && localFH.genFlag == 8)
 			{
 			break;
@@ -143,25 +159,32 @@ unsigned char *extract_zip(f_state *s, u_int64_t c_offset, unsigned char *founda
 			{
 			break;
 			}
-		}
-
+			
+		
+	}//end while loop
+	
 	if (oOffice)
 		{
 
-		/*We have an OO doc how long should we search for?*/
+		//We have an OO doc how long should we search for?
 		bytes_to_search = 1 * MEGABYTE;
 		}
+	else if (localFH.genFlag & 1<<3 && localFH.uncompressed==0 &&  localFH.compressed==0 )
+		{
+		bytes_to_search = needle->max_len;
+		}
 	else
 		{
 		bytes_to_search = (foundat - buf);
 		}
 
-	/*Make sure we are not searching more than what he have*/
+	//Make sure we are not searching more than what he have
 	if (buflen - (foundat - buf) < bytes_to_search)
 		{
 		bytes_to_search = buflen - (foundat - buf);
 		}
 
+
 	currentpos = foundat;
 #ifdef DEBUG
 	printf("Search for the footer bytes_to_search:=%lld buflen:=%lld\n", bytes_to_search, buflen);
@@ -195,7 +218,7 @@ unsigned char *extract_zip(f_state *s, u_int64_t c_offset, unsigned char *founda
 			}
 
 		comment_length = htos(foundat, LITTLE_ENDIAN);
-		foundat += comment_length + 1;
+		foundat += comment_length + 2;
 		file_size = (foundat - buf);
 #ifdef DEBUG
 		printf("File size %lld\n", file_size);
@@ -2090,6 +2113,34 @@ unsigned char *extract_exe(f_state *s, u_int64_t c_offset, unsigned char *founda
 	return (buf + file_size);
 }
 
+
+/********************************************************************************
+ *Function: extract_reg
+ *Description:
+ *Return: A pointer to where the EOF of the
+ **********************************************************************************/
+unsigned char *extract_reg(f_state *s, u_int64_t c_offset, unsigned char *foundat, u_int64_t buflen,
+						   s_spec *needle, u_int64_t f_offset)
+{
+	unsigned char	*buf = foundat;
+	unsigned char	*extractbuf = NULL;
+	int sizeofreg = htoi(&foundat[0x28], FOREMOST_LITTLE_ENDIAN);
+	int file_size=0;
+	if(sizeofreg < 0 || sizeofreg > needle->max_len)	
+	{
+		return (foundat+4);
+	}	
+	foundat+=sizeofreg;
+	file_size = (foundat - buf);
+
+	extractbuf = buf;
+
+
+	write_to_disk(s, needle, file_size , extractbuf, c_offset + f_offset);
+
+			
+	return NULL;
+}
 /********************************************************************************
  *Function: extract_rar
  *Description:
@@ -2353,7 +2404,6 @@ unsigned char *extract_file(f_state *s, u_int64_t c_offset, unsigned char *found
 		}
 	else if (needle->type == SXW)
 		{
-
 		return extract_zip(s, c_offset, foundat, buflen, needle, f_offset, "sxw");
 		}
 	else if (needle->type == SXC)
@@ -2380,4 +2430,5 @@ unsigned char *extract_file(f_state *s, u_int64_t c_offset, unsigned char *found
 		{
 		return NULL;
 		}
+	return NULL;	
 }
