@@ -247,6 +247,8 @@ char *__progname;
 #define PNG 24
 #define RAR 25
 #define EXE 26
+#define ELF 27
+#define REG 28
 
 #define KILOBYTE                  1024
 #define MEGABYTE                  1024 * KILOBYTE
