@@ -373,9 +373,24 @@ int set_search_def(f_state *s, char *ft, u_int64_t max_file_size)
 			max_file_size = 1 * MEGABYTE;
 
 		init_builtin(s, EXE, "exe", "MZ", NULL, 2, 0, max_file_size, TRUE);
-
-		//init_builtin(s,PE,"exe","PE",NULL,2,0,max_file_size,TRUE);
 		}
+	else if (strcmp(ft, "elf") == 0)
+		{
+
+		if (max_file_size == 0)
+			max_file_size = 1 * MEGABYTE;
+
+		init_builtin(s, ELF, "elf", "0x7fELF", NULL, 4, 0, max_file_size, TRUE);
+		}	
+	else if (strcmp(ft, "reg") == 0)
+		{
+
+		if (max_file_size == 0)
+			max_file_size = 2 * MEGABYTE;
+
+		init_builtin(s, REG, "reg", "regf", NULL, 4, 0, max_file_size, TRUE);
+
+		}	
 	else if (strcmp(ft, "mpg") == 0 || strcmp(ft, "mpeg") == 0)
 		{
 		if (max_file_size == 0)
@@ -516,7 +531,7 @@ int set_search_def(f_state *s, char *ft, u_int64_t max_file_size)
 					 ZIP,
 					 "zip",
 					 "\x50\x4B\x03\x04",
-					 "\x4b\x05\x06\x00",
+					 "\x50\x4b\x05\x06",
 					 4,
 					 4,
 					 max_file_size,
